@@ -324,7 +324,7 @@ static void add_to_dialog(GtkWidget *dialog, GtkWidget *thing)
 #endif
 }
 /* Editing the metadata... */
-static void edit_dialog_create()
+static void edit_dialog_create(void)
 {
   GtkWidget *hbox, *label, *dialog, *tempwid, *entry;
 #if !GTK_CHECK_VERSION(2,6,0)
