@@ -742,7 +742,7 @@ void fill_in_dir(listtype_t listtype, gchar *path)
   g_thread_create(dirfill_thread,(gpointer) dirfill_thread_args, FALSE, NULL);
 }
 
-gchar *get_current_dir()
+gchar *get_current_dir(void)
 {
   gchar *tmp, *path;
 
