@@ -146,19 +146,6 @@ static const mtp_filetype_description_t mtp_filetype_descriptions[] = {
 
 /* Local static functions */
 
-/* Return disk usage */
-static void jukebox_getusage(guint64 *total, guint64 *free, guint64 *used, 
-			     guint32 *songs, guint32 *playlists, guint32 *datafiles)
-{
-  *total = jukebox_totalbytes;
-  *free = jukebox_freebytes;
-  *used = jukebox_usedbytes;
-  *songs = jukebox_songs;
-  *playlists = jukebox_playlists;
-  *datafiles = jukebox_datafiles;
-}
-
-
 static const mtp_filetype_description_t*
 get_mtp_filetype_description(LIBMTP_filetype_t type) {
   const mtp_filetype_description_t *current;
@@ -186,6 +173,18 @@ get_mtp_filetype_description_by_codec(const gchar *name) {
 }
 #endif
 
+/* Return disk usage */
+static void jukebox_getusage(guint64 *total, guint64 *free, guint64 *used, 
+			     guint32 *songs, guint32 *playlists, guint32 *datafiles)
+{
+  *total = jukebox_totalbytes;
+  *free = jukebox_freebytes;
+  *used = jukebox_usedbytes;
+  *songs = jukebox_songs;
+  *playlists = jukebox_playlists;
+  *datafiles = jukebox_datafiles;
+}
+
 /***********************************************************************************/
 /* Public and private functions                                                    */
 /***********************************************************************************/
@@ -683,7 +682,7 @@ static void destroy_hash (gpointer key,
 }
 
 
-static void destroy_hashes()
+static void destroy_hashes(void)
 {
   /* Destroy the song hash */
   if (songhash != NULL) {
@@ -928,7 +927,7 @@ void jukebox_release(void)
 
 /* Builds the list in memory that the dialog
  * drop down is then built from */
-static void build_playlist_list()
+static void build_playlist_list(void)
 {
   // Make sure we destroyed the old playlist list
   if (playlistlist != NULL) {
@@ -1085,7 +1084,7 @@ static void build_tree_widget(GtkTreeStore *pltreestore)
   }
 }
 
-static void destroy_tree_structure()
+static void destroy_tree_structure(void)
 {
   /* This destroys the playlists in memory again */
   GSList *tmplist;
@@ -1133,7 +1132,7 @@ static gboolean call_build_playlist_tree(gpointer data)
 }
 
 /* Update the usage information */
-static void flush_usage()
+static void flush_usage(void)
 {
   u_int64_t totalbytes = 0;
   u_int64_t freebytes = 0;
@@ -1164,7 +1163,7 @@ static void flush_usage()
   jukebox_usedbytes = jukebox_totalbytes - jukebox_freebytes;
 }
 
-static void destroy_datafile_list()
+static void destroy_datafile_list(void)
 {
   GSList *tmplist = datafilelist;
   metadata_t *meta;
