@@ -20,7 +20,7 @@ Boston, MA 02111-1307, USA.
 #include "metadata.h"
 #include "util.h"
 
-metadata_t *new_metadata_t()
+metadata_t *new_metadata_t(void)
 {
   metadata_t *meta;
 
@@ -528,7 +528,7 @@ gint sort_iter_compare_func(GtkTreeModel *model,
     return ret;
 }
 
-static GtkListStore *create_hdliststore()
+static GtkListStore *create_hdliststore(void)
 {
   GtkListStore *hdliststore;
   GtkTreeSortable *sortable;
@@ -566,7 +566,7 @@ static GtkListStore *create_hdliststore()
   return hdliststore;
 }
 
-static GtkListStore *create_jbliststore()
+static GtkListStore *create_jbliststore(void)
 {
   GtkListStore *jbliststore;
   GtkTreeSortable *sortable;
@@ -604,7 +604,7 @@ static GtkListStore *create_jbliststore()
   return jbliststore;
 }
 
-static GtkListStore *create_hddataliststore()
+static GtkListStore *create_hddataliststore(void)
 {
   GtkListStore *hddataliststore;
 
@@ -618,7 +618,7 @@ static GtkListStore *create_hddataliststore()
   return hddataliststore;
 }
 
-static GtkListStore *create_jbdataliststore()
+static GtkListStore *create_jbdataliststore(void)
 {
   GtkListStore *jbdataliststore;
 
@@ -912,7 +912,7 @@ void recreate_list_store(listtype_t listtype)
     data_widgets.jbliststore = create_jbdataliststore();  
 }
 
-void create_list_stores()
+void create_list_stores(void)
 {
   /* The list stores */
   GtkTreeStore *pltreestore;
