@@ -276,7 +276,7 @@ static void toggle_onoff (GtkCheckButton *toggle,
 }
 
 
-static GtkWidget *get_eax_controls()
+static GtkWidget *get_eax_controls(void)
 {
   njb_eax_t *eax;
   GtkWidget *hbox;
