@@ -60,7 +60,7 @@ static gchar *get_text_from_selection_column(gint column)
   return text;
 }
 
-static guint32 get_playlistid_from_selection()
+static guint32 get_playlistid_from_selection(void)
 {
   gchar *text = NULL;
   guint32 plid = 0;
@@ -73,7 +73,7 @@ static guint32 get_playlistid_from_selection()
   return plid;
 }
 
-static guint32 get_trackid_from_selection()
+static guint32 get_trackid_from_selection(void)
 {
   gchar *text = NULL;
   guint32 trackid = 0;
@@ -87,7 +87,7 @@ static guint32 get_trackid_from_selection()
 }
 
 
-static void remove_selected_row()
+static void remove_selected_row(void)
 {
   GtkTreeSelection *selection;
   GtkTreeIter iter;
@@ -650,7 +650,7 @@ static GCallback mouseevent (GtkWidget      *clist,
   return data;
 }
 
-static GtkWidget *create_option_menu()
+static GtkWidget *create_option_menu(void)
 {
   GtkWidget *option_menu;
   GSList *group = NULL;
@@ -785,7 +785,7 @@ static void playlist_selection_dialog(gchar *title, gchar *prompt, GtkSignalFunc
 }
 
 /* Find the playlists selected for addition */
-static GList *get_selected_playlists()
+static GList *get_selected_playlists(void)
 {
   GList *templist;
   GList *retlist = NULL;
