@@ -28,6 +28,10 @@ scratch.
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#if GLIB_CHECK_VERSION(2,6,0)
+#   include <glib.h>
+#   include <glib/gstdio.h>
+#endif
 
 static gboolean
 guid_compare(guchar *guid1, guchar *guid2)
@@ -80,9 +84,9 @@ parse_content_description(guchar *data, guint size, metadata_t *meta)
   // Rating               WCHAR       16      // array of Unicode characters - Rating
   guint title_length = (data[25] << 8) + data[24];
   guint author_length = (data[27] << 8) + data[26];
-  guint copyright_length = (data[29] << 8) + data[28];
-  guint description_length = (data[31] << 8) + data[30];
-  guint rating_length = (data[33] << 8) + data[32];
+  // guint copyright_length = (data[29] << 8) + data[28];
+  // guint description_length = (data[31] << 8) + data[30];
+  // guint rating_length = (data[33] << 8) + data[32];
   guint offset = 34; // Points to first string
 
   if ((title_length > 0) && (meta->title == NULL)) {
@@ -157,10 +161,10 @@ parse_extended_content_description(guchar *data, guint size, metadata_t *meta)
 	}
 	meta->album = desc_string;
       } else if(!strcmp(desc_name, "WM/Year") || !strcmp(desc_name, "Year")) {
-	meta->year = string_to_guint(desc_string);
+	meta->year = string_to_guint32(desc_string);
 	g_free(desc_string);
       } else if(!strcmp(desc_name, "WM/TrackNumber") || !strcmp(desc_name, "TrackNumber")) {
-	meta->trackno = string_to_guint(desc_string);
+	meta->trackno = string_to_guint32(desc_string);
 	g_free(desc_string);
       } else {
 	g_free(desc_string);
@@ -376,7 +380,7 @@ get_tag_for_wmafile (metadata_t *meta)
     //meta->title = getTitle(tag);
     //meta->album = getAlbum(tag);
     //meta->genre = getGenre(tag);
-    //meta->year = string_to_guint(getYear(tag));
+    //meta->year = string_to_guint32(getYear(tag));
     
     /* If there is a songlength tag it will take
      * precedence over any length calculated from
