@@ -379,7 +379,7 @@ static GCallback hdmenu_new_folder_response(gpointer data)
 }
 
 /* Handles descending into a directory in the clist */
-static void go_down()
+static void go_down(void)
 {
   gchar *path;
   metadata_t *meta;
@@ -579,18 +579,21 @@ static GtkWidget *create_listview(GtkListStore *liststore)
   listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(liststore));
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(listview), TRUE);
   
-  dirtextrenderer = gtk_cell_renderer_text_new ();
-  textrenderer = gtk_cell_renderer_text_new ();
+  dirtextrenderer = gtk_cell_renderer_text_new();
+  textrenderer = gtk_cell_renderer_text_new();
   /* This renderer render time measures */
-  timerenderer = gtk_cell_renderer_text_new ();
-  /* Property set example:
+  timerenderer = gtk_cell_renderer_text_new();
+
+  g_object_set(G_OBJECT(textrenderer),
+	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+	       "weight", NULL,
+	       "underline", FALSE,
+	       NULL);
   g_object_set(G_OBJECT(timerenderer),
-	       "font", "Sans 12",
-	       "foreground", "blue", 
-	       "weight", "bold",
-	       "underline", TRUE,
+	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+	       "weight", NULL,
+	       "underline", FALSE,
 	       NULL);
-  */
 
   togglerenderer = gtk_cell_renderer_toggle_new ();
 
@@ -614,6 +617,7 @@ static GtkWidget *create_listview(GtkListStore *liststore)
 						   textrenderer,
 						   "text", TRACKLIST_TITLE_COLUMN,
 						   NULL);
+  // FIXME: color this
   gtk_tree_view_column_set_sizing (view, GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(view, TRUE);
   gtk_tree_view_column_set_fixed_width(view, 150);
@@ -740,7 +744,7 @@ static GtkWidget *create_listview(GtkListStore *liststore)
 }
 
 
-GtkWidget *create_xfer_widgets()
+GtkWidget *create_xfer_widgets(void)
 {
   GtkWidget *popupmenu, *popupmenu_item;
   GtkWidget *button;
